<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DraftMode</name>
    <message>
        <location filename="../DraftMode.js" line="+86"/>
        <source>&amp;Draft Mode</source>
        <translation>Návrhový režim</translation>
    </message>
</context>
</TS>
